kms

package
v0.0.0-...-cef0c6a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AWSSigner

type AWSSigner struct {
	// contains filtered or unexported fields
}

AWSSigner implements auth.Signer using AWS KMS.

func NewAWSSigner

func NewAWSSigner(ctx context.Context, client *kms.Client, keyID string, chainID int64) (*AWSSigner, error)

NewAWSSigner creates a new signer backed by an AWS KMS key. It fetches the public key from KMS to compute the address.

func NewAWSSignerWithTimeout

func NewAWSSignerWithTimeout(ctx context.Context, client *kms.Client, keyID string, chainID int64, timeout time.Duration) (*AWSSigner, error)

NewAWSSignerWithTimeout creates a new signer with a custom timeout for KMS operations.

func (*AWSSigner) Address

func (s *AWSSigner) Address() common.Address

func (*AWSSigner) ChainID

func (s *AWSSigner) ChainID() *big.Int

func (*AWSSigner) SignTypedData

func (s *AWSSigner) SignTypedData(domain *apitypes.TypedDataDomain, typesDef apitypes.Types, message apitypes.TypedDataMessage, primaryType string) ([]byte, error)

SignTypedData signs EIP-712 typed data using AWS KMS.

Jump to